#
# spec file for package python-aws-sam-translator
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-aws-sam-translator
Version:        1.11.0
Release:        lp152.1.1
Summary:        AWS SAM template to AWS CloudFormation template translator
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/awslabs/serverless-application-model
Source:         https://github.com/awslabs/serverless-application-model/archive/v%{version}.tar.gz#/serverless-application-model-%{version}.tar.gz
Patch:          ast_drop-compatible-releases-operator.patch
%if 0%{?suse_version} < 1500
BuildRequires:  python
%endif
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module PyYAML >= 4.2}
BuildRequires:  %{python_module boto3 >= 1.5}
BuildRequires:  %{python_module coverage >= 4.4.0}
BuildRequires:  %{python_module jsonschema >= 2.6}
BuildRequires:  %{python_module mock >= 2.0.0}
BuildRequires:  %{python_module parameterized >= 0.6.1}
BuildRequires:  %{python_module py >= 1.4.33}
BuildRequires:  %{python_module pytest >= 3.0.7}
BuildRequires:  %{python_module pytest-cov >= 2.4.0}
BuildRequires:  %{python_module requests >= 2.20.0}
BuildRequires:  %{python_module six >= 1.11}
BuildRequires:  python-enum34 >= 1.1
# /SECTION
Requires:       python-PyYAML >= 4.2
Requires:       python-boto3 >= 1.5
Requires:       python-docopt >= 0.6.2
Requires:       python-jsonschema >= 2.6
Requires:       python-six >= 1.11
%ifpython2
Requires:       python-enum34 >= 1.1
%endif
BuildArch:      noarch

%python_subpackages

%description
AWS SAM Translator is a library that transform SAM
templates into AWS CloudFormation templates

%prep
%setup -q -n serverless-application-model-%{version}
%patch -p1
sed -i -e '1s|#!/usr/bin/env python2|#!/usr/bin/python3|' bin/sam-translate.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

mkdir -p %{buildroot}%{_bindir}
install -D -m 644 bin/sam-translate.py %{buildroot}%{_bindir}/sam-translate

%check
export LANG=en_US.UTF8
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%python3_only %{_bindir}/sam-translate
%{python_sitelib}/*

%changelog
* Fri Dec 13 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1159018, jsc#PM-1507)
* Fri Jul 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update the patch ast_drop-compatible-releases-operator.patch to
  not pull enum34 on python3
* Thu Jul 11 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Fix build on SLE-12
  + Add python to BuildRequires for suse_version < 1500
  + Set LANG to en_US.UTF8 before running testsuite
  + Refresh ast_drop-compatible-releases-operator.patch to
    strip "python_version<"3.4"" from install_requires
* Wed Jun  5 2019 Todd R <toddrme2178@gmail.com>
- Switch to github sources which include tests
- Enable tests
- Fix dependencies
- Add commandline tool
* Fri May 17 2019 Scott Wulf <swulf@suse.com>
- Upgrade to 1.11.0
  * Add ReservedConcurrentExecutions to globals
  * Fix ElasticsearchHttpPostPolicy resource reference
  * Support using AWS::Region in Ref and Sub
  * Documentation and examples updates
  * Add VersionDescription property to Serverless::Function
  * Update ServerlessRepoReadWriteAccessPolicy
  * Add additional template validation
- Upgrade to 1.10.0
  * Add GSIs to DynamoDBReadPolicy and DynamoDBCrudPolicy
  * Add DynamoDBReconfigurePolicy
  * Add CostExplorerReadOnlyPolicy and OrganizationsListAccountsPolicy
  * Add EKSDescribePolicy
  * Add SESBulkTemplatedCrudPolicy
  * Add FilterLogEventsPolicy
  * Add SSMParameterReadPolicy
  * Add SESEmailTemplateCrudPolicy
  * Add s3:PutObjectAcl to S3CrudPolicy
  * Add allow_credentials CORS option
  * Add support for AccessLogSetting and CanarySetting Serverless::Api properties
  * Add support for X-Ray in Serverless::Api
  * Add support for MinimumCompressionSize in Serverless::Api
  * Add Auth to Serverless::Api globals
  * Remove trailing slashes from APIGW permissions
  * Add SNS FilterPolicy and an example application
  * Add Enabled property to Serverless::Function event sources
  * Add support for PermissionsBoundary in Serverless::Function
  * Fix boto3 client initialization
  * Add PublicAccessBlockConfiguration property to S3 bucket resource
  * Make PAY_PER_REQUEST default mode for Serverless::SimpleTable
  * Add limited support for resolving intrinsics in Serverless::LayerVersion
  * SAM now uses Flake8
  * Add example application for S3 Events written in Go
  * Updated several example applications
* Mon Jan 21 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include in SLE-15 (FATE#326961, bsc#1122669)
* Mon Jan 21 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.9.0
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + ast_drop-compatible-releases-operator.patch
